AnalyticsDelegate class abstract

Defines a delegate to handle analytics operations.

Constructors

AnalyticsDelegate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

error(AnalyticsError error) Future<void>
Called when an error is logged.
event(AnalyticsEvent event) Future<void>
Called when an event is logged.
failure(AnalyticsEvent event) Future<void>
Called when an event is logged failed.
log(AnalyticsEvent event) Future<void>
Called when a generic log message is written.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
platform(Object error, StackTrace stackTrace) → void
toString() String
A string representation of this object.
inherited
widget(FlutterErrorDetails details) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited