AnalyticsErrorType enum

Defines possible types of analytics errors.

Inheritance
Available extensions

Values

assertion → const AnalyticsErrorType

Represents an AssertionError.

widget → const AnalyticsErrorType

Represents a runtime widget error or exception.

platform → const AnalyticsErrorType

Represents a platform-level error.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(Object? source) AnalyticsErrorType?
Parses a source value into an AnalyticsErrorType if possible.

Constants

values → const List<AnalyticsErrorType>
A constant List of the values in this enum, in order of their declaration.