AnalyticsEvent class

Represents a logged analytics event.

Constructors

AnalyticsEvent.create(String name, {String? reason, String? sign, String? msg, Map<String, Object>? props})
Creates an AnalyticsEvent from the current time and platform.
factory
AnalyticsEvent.empty()
Creates an empty AnalyticsEvent.
const
AnalyticsEvent.params(String name, Map<String, Object> parameters)
factory
AnalyticsEvent.parse(Object? source)
Parses a JSON-like Map into an AnalyticsEvent.
factory

Properties

extra Map<String, Object>?
final
hashCode int
The hash code for this object.
no setterinherited
json Map<String, dynamic>?
Returns this event as a JSON-compatible Map.
no setter
msg String?
An optional event message.
final
name String
The event name.
final
platform String?
The platform where the event was logged.
final
props Map<String, Object>?
Optional custom event properties.
final
reason String?
The event reason.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sign String?
The optional message sign.
final
time int
The timestamp in milliseconds.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited