AnalyticsFuture<T extends Object?> extension

Extension on Future<T> to automatically log analytics for operations returning a value of type T.

Provides analytics method that wraps the future and logs success/failure using the global Analytics manager.

on

Methods

analytics({String? name, String? msg}) Future<T?>

Available on Future<T>, provided by the AnalyticsFuture extension

Executes the future and logs analytics automatically.