EventItem class
Constructors
EventItem ({String ? affiliation , String ? currency , String ? coupon , String ? creativeName , String ? creativeSlot , num ? discount , int ? index , String ? itemBrand , String ? itemCategory , String ? itemCategory2 , String ? itemCategory3 , String ? itemCategory4 , String ? itemCategory5 , String ? itemId , String ? itemListId , String ? itemListName , String ? itemName , String ? itemVariant , String ? locationId , num ? price , String ? promotionId , String ? promotionName , int ? quantity , Map <String , Object > ? parameters })
const
Properties
affiliation
→ String ?
A product affiliation to designate a supplying company or brick and
mortar store location.
e.g. Google Store
final
coupon
→ String ?
The coupon name/code associated with the item.
e.g. SUMMER_FUN
final
creativeName
→ String ?
The name of the promotional creative.
final
creativeSlot
→ String ?
The name of the promotional creative slot associated with the item.
final
currency
→ String ?
The currency, in 3-letter ISO 4217 format.
If set, event-level currency is ignored.
Multiple currencies per event is not supported. Each item should set the
same currency.
e.g. USD
final
discount
→ num ?
The monetary discount value associated with the item.
e.g. 2.22
final
hashCode
→ int
The hash code for this object.
no setter inherited
index
→ int ?
The index/position of the item in a list.
e.g. 5
final
itemBrand
→ String ?
The brand of the item.
e.g. Google
final
itemCategory
→ String ?
The category of the item. If used as part of a category hierarchy or
taxonomy then this will be the first category.
e.g. Apparel
final
itemCategory2
→ String ?
The second category hierarchy or additional taxonomy for the item.
e.g. Adult
final
itemCategory3
→ String ?
The third category hierarchy or additional taxonomy for the item.
e.g. Shirts
final
itemCategory4
→ String ?
The fourth category hierarchy or additional taxonomy for the item.
e.g. Crew
final
itemCategory5
→ String ?
The fifth category hierarchy or additional taxonomy for the item.
e.g. Short sleeve
final
itemId
→ String ?
The ID of the item.
One of itemId or itemName is required.
e.g. SKU_12345
final
itemListId
→ String ?
The ID of the list in which the item was presented to the user.
e.g. related_products
final
itemListName
→ String ?
The name of the list in which the item was presented to the user.
e.g. Related products
final
itemName
→ String ?
The name of the item.
One of itemId or itemName is required.
e.g. Stan and Friends Tee
final
itemVariant
→ String ?
The item variant or unique code or description for additional item details/options.
e.g. green
final
locationId
→ String ?
The location associated with the item. It's recommended to use the Google
Place ID that corresponds to the associated item. A custom location ID can
also be used.
e.g. L_12345
final
parameters
→ Map <String , Object > ?
Extra parameters to pass along default ones
final
price
→ num ?
The monetary price of the item, in units of the specified currency parameter.
e.g. 9.99
final
promotionId
→ String ?
The ID of the promotion associated with the item.
e.g. P_12345
final
promotionName
→ String ?
The name of the promotion associated with the item.
e.g. Summer Sale
final
quantity
→ int ?
Item quantity.
e.g. 1
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited