analytics library

Classes

Analytics
The main analytics manager used to record events and errors.
AnalyticsError
Represents an analytics error, including time, platform, and details.
AnalyticsEvent
Represents a logged analytics event.
EventFields
EventItem
Events

Enums

AnalyticsErrorType
Defines possible types of analytics errors.

Extensions

AnalyticsFuture on Future<T>
Extension on Future<T> to automatically log analytics for operations returning a value of type T.
AnalyticsStream on Stream<T?>
Extension on Stream<T> to automatically log analytics for streaming operations.

Constants

kAnalytics → const String
The default analytics name identifier.