AnalyticsError class
Represents an analytics error, including time, platform, and details.
Constructors
- AnalyticsError({String? time, String? platform, String? msg, String? sign, String? details, AnalyticsErrorType? type})
-
Creates a new AnalyticsError.
const
- AnalyticsError.empty()
-
Creates an empty AnalyticsError instance.
const
- AnalyticsError.error(FlutterErrorDetails details)
-
Creates an error report from a FlutterErrorDetails object.
factory
- AnalyticsError.parse(Object? source)
-
Parses a JSON-like Map into an AnalyticsError instance.
factory
- AnalyticsError.platform(Object exception, StackTrace stackTrace)
-
Creates a platform-specific error report from an
exceptionandstackTrace.factory
Properties
- details → String?
-
Additional error details or stack trace.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
json
→ Map<
String, dynamic> ? -
Returns this object as a JSON-compatible Map.
no setter
- msg → String?
-
The error message.
final
- platform → String?
-
The platform where the error occurred.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sign → String?
-
The error sign.
final
- time → String?
-
The timestamp when the error occurred.
final
- type → AnalyticsErrorType?
-
The type of the analytics error.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited