Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- affiliation → const String
- campaign → const String
- character → const String
- contentType → const String
- coupon → const String
- currency → const String
- groupId → const String
- id → const String
- itemCategory → const String
- itemId → const String
- itemList → const String
- itemListId → const String
- itemListName → const String
- itemName → const String
- items → const String
- level → const String
- levelName → const String
- loginMethod → const String
- medium → const String
- method → const String
- parameters → const String
- paymentType → const String
- promotionId → const String
- promotionName → const String
- score → const String
- screenClass → const String
- screenName → const String
- searchTerm → const String
- shipping → const String
- shippingTier → const String
- signUpMethod → const String
- source → const String
- success → const String
- tax → const String
- transactionId → const String
- value → const String
- virtualCurrencyName → const String